@@ -1,6 +1,6 @@
 package Object::Simple;
 
-our $VERSION = '3.16';
+our $VERSION = '3.17';
 
 use strict;
 use warnings;
@@ -167,7 +167,23 @@ sub dual_attr {
 
 =head1 NAME
 
-Object::Simple - Simple class builder(Mojo::Base porting)
+Object::Simple - Simplest class builder, Mojo::Base porting
+
+=over
+
+=item 1.
+
+B<Simplest class builder>. All you learn is only C<has> function.
+
+=item 2.
+
+B<Mojo::Base porting>. Do you like L<Mojolicious>? If so, this is good choices!
+
+=item 3.
+
+B<Fast and less memory>. Fast C<new> method, Fast accessor method.
+
+=back
 
 =head1 SYNOPSIS
 
@@ -217,20 +233,27 @@ Inheritance
 
 =head1 DESCRIPTION
 
-L<Object::Simple> is L<Mojo::Base> porting.
-you can use L<Mojo::Base> features.
+B<Simplest class builder>: All you learn is only C<has> function.
+You can learn all features of L<Object::Simple> in one hour 
 
-L<Object::Simple> is a generator of accessor method,
-such as L<Class::Accessor>, L<Mojo::Base>, or L<Moose>.
+B<Mojo::Base porting>: Do you like L<Mojolicious>? If so, this is good choices!
+If you have known L<Mojo::Base>, you don't learn anything.
 
-L<Class::Accessor> is simple, but lack offten used features.
+B<Fast and less memory>: Fast C<new> method, Fast accessor method.
+In pure perl implementation, this module is much fast.
+
+B<Object::Simple vs Class::Accessor::Fast>
+
+L<Class::Accessor::Fast> is simple, but lack offten used features.
 C<new> method can't receive hash arguments.
 Default value can't be specified.
 If multipule values is set through the accessor,
 its value is converted to array reference without warnings.
 
-Some people find L<Moose> too complex, and dislike that 
-it depends on outside modules. Some say that L<Moose> is 
+B<Object::Simple vs Moose>
+
+Some people find L<Moose> too complex, and dislike it because
+it depends on much many modules. Some one say that L<Moose> is 
 almost like another language and does not fit the familiar 
 perl syntax. In some cases, in particular smaller projects, 
 some people feel that L<Moose> will increase complexity
@@ -238,19 +261,9 @@ and therefore decrease programmer efficiency.
 In addition, L<Moose> can be slow at compile-time and 
 its memory usage can get large.
 
-L<Object::Simple> is the middle way between L<Class::Accessor>
-and complex class builder. Only offten used features is
-implemented has no dependency.
-L<Object::Simple> is almost same as L<Mojo::Base>.
+=head1 TUTORIAL
 
-C<new> method can receive hash or hash reference.
-You can specify default value.
-
-If you like L<Mojo::Base>, L<Object::Simple> is good choice.
-
-=head1 GUIDE
-
-=head2 1. Create accessor
+=head2 1. Define class and create accessor
 
 At first, you create class.
 
@@ -303,7 +316,39 @@ You can create multiple accessors at once.
   has [qw/foo bar baz/];
   has [qw/foo bar baz/] => 0;
 
-=head2 Class example
+=head2 2. Override method
+
+Method can be overridden.
+
+B<Example:>
+
+Initialize the object
+
+  sub new {
+    my $self = shift->SUPER::new(@_);
+    
+    # Initialization
+    
+    return $self;
+  }
+
+B<Example:>
+
+Change arguments of C<new>.
+  
+  sub new {
+    my $self = shift;
+    
+    $self->SUPER::new(x => $_[0], y => $_[1]);
+    
+    return $self;
+  }
+
+You can pass array to C<new> method.
+
+  my $point = Point->new(4, 5);
+
+=head2 3. Class example
 
 I introduce L<Object::Simple> example.
 
@@ -356,9 +401,9 @@ Use Point3D class.
   $point->z(9);
   $point->clear;
 
-=head2 2. Concepts of Object-Oriented programing
+=head2 4. Easy description of Object-Oriented programing
 
-I introduce concepts of Object-Oriented programing
+I introduce concepts of Object-Oriented programing.
 
 =head3 Inheritance
 
@@ -476,68 +521,6 @@ use SUPER pseudo-class.
 If you understand three concepts,
 you have learned Object-Oriented programming primary parts.
 
-=head2 3. Often used techniques
-
-=head3 Override new method
-
-C<new> method can be overridden.
-
-B<Example:>
-
-Initialize the object
-
-  sub new {
-    my $self = shift->SUPER::new(@_);
-    
-    # Initialization
-    
-    return $self;
-  }
-
-B<Example:>
-
-Change arguments of C<new>.
-  
-  sub new {
-    my $self = shift;
-    
-    $self->SUPER::new(x => $_[0], y => $_[1]);
-    
-    return $self;
-  }
-
-You can pass array to C<new> method.
-
-  my $point = Point->new(4, 5);
-
-=head1 IMPORT OPTIONS
-
-=head2 -base
-
-By using C<-base> option, the class inherit Object::Simple
-and import C<has> function.
-
-  package Foo;
-  use Object::Simple -base;
-  
-  has x => 1;
-  has y => 2;
-
-strict and warnings is automatically enabled.
-
-You can also use C<-base> option in sub class
-to inherit other class.
-  
-  # Bar inherit Foo
-  package Bar;
-  use Foo -base;
-
-You can also use the following syntax.
-
-  # Same as above
-  package Bar;
-  use Object::Simple -base => 'Foo';
-
 =head1 FUNCTIONS
 
 =head2 has
@@ -598,17 +581,33 @@ hash or hash reference as arguments.
 Create accessor.
 C<attr> method usage is equal to C<has> method.
 
-=head1 DEPRECATED FUNCTIONALITY
+=head1 OPTIONS
 
-  function exporting of C<new> and C<attr> method # Will be removed 2021/6/1
+=head2 -base
+
+By using C<-base> option, the class inherit Object::Simple
+and import C<has> function.
+
+  package Foo;
+  use Object::Simple -base;
   
-  The syntax of multiple key-value arguments 
-    has x => 1, y => 2;      
-    __PACAKGE__->attr(x => 1, y => 2);
-  # Will be removed 2021/6/1
+  has x => 1;
+  has y => 2;
+
+strict and warnings is automatically enabled.
+
+You can also use C<-base> option in sub class
+to inherit other class.
   
-  class_attr method # will be removed 2017/1/1
-  dual_attr method # will be removed 2017/1/1
+  # Bar inherit Foo
+  package Bar;
+  use Foo -base;
+
+You can also use the following syntax.
+
+  # Same as above
+  package Bar;
+  use Object::Simple -base => 'Foo';
 
 =head1 BACKWARDS COMPATIBILITY POLICY
 
@@ -622,6 +621,18 @@ EXPERIMENTAL functionality will be changed without warnings.
 
 (This policy was changed at 2011/10/22)
 
+=head1 DEPRECATED
+
+  function exporting of C<new> and C<attr> method # Will be removed 2021/6/1
+  
+  The syntax of multiple key-value arguments 
+    has x => 1, y => 2;      
+    __PACAKGE__->attr(x => 1, y => 2);
+  # Will be removed 2021/6/1
+  
+  class_attr method # will be removed 2017/1/1
+  dual_attr method # will be removed 2017/1/1
+
 =head1 BUGS
 
 Tell me the bugs
@@ -638,6 +649,30 @@ Copyright 2008-2016 Yuki Kimoto, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Artistic v2(This is same as L<Mojolicious> licence).
 
+=head1 Object::Simple used projects
+
+L<Object::Simple> is used in the following projects.
+
+=over 4
+
+=item *
+
+GitPrep - Portable GitHub system into your own server L<https://github.com/yuki-kimoto/gitprep>
+
+=item *
+
+L<DBIx::Custom> - DBI extension to execute insert, update, delete, and select easily
+
+=item *
+
+L<Validator::Custom> - HTML form Validation, simple and good flexibility
+
+=back
+
+=head1 SEE ALSO
+
+L<Mojo::Base>, L<Class::Accessor>, L<Class::Accessor::Fast>, L<Moose>, L<Moo>.
+
 =cut
 
 1;
